==> progamification-0.0.8.tar.gz: lib/src/components/user_details.dart <==
import 'package:flutter/material.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:get/get.dart';

class UserDetails extends StatefulWidget {
  const UserDetails({super.key});

  @override
  State<UserDetails> createState() => _UserDetailsState();
}

class _UserDetailsState extends State<UserDetails> {
  final LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  final GamificationStorageService storageService =
      Get.find<GamificationStorageService>();

  LeaderBoardModel? currentUser = LeaderBoardModel();
  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";
  @override
  void initState() {
    setCurrentUserLeaderBoardData();
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(
          top: MediaQuery.of(context).size.height * 0.02,
          bottom: MediaQuery.of(context).size.height * 0.02),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          Column(crossAxisAlignment: CrossAxisAlignment.center, children: [
            const Text('Points',
                style: TextStyle(
                    color: Colors.grey,
                    fontWeight: FontWeight.w800,
                    fontSize: 22,
                    fontFamily: 'Roboto')),
            Text(currentUser != null ? currentUser!.score.toString() : '0',
                style: const TextStyle(
                    color: Colors.black,
                    fontWeight: FontWeight.w600,
                    fontSize: 26,
                    fontFamily: 'Roboto')),
          ]),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 8, vertical: 8),
            child: Container(
              width: 60,
              height: 60,
              decoration: const BoxDecoration(
                shape: BoxShape.circle,
              ),
              child: ClipOval(
                child: Image.network(
                    currentUser!.profileImageUrl!.toString() + sasToken,
                    fit: BoxFit.cover,
                    errorBuilder: (context, child, loadingProgress) => SizedBox(
                        width: 60.0,
                        height: 60.0,
                        child: Image.asset(
                            'assets/icons/profile_placeholder.png',
                            package: 'progamification'))),
              ),
            ),
          ),
          Column(crossAxisAlignment: CrossAxisAlignment.center, children: [
            const Text('Rank',
                style: TextStyle(
                    color: Colors.grey,
                    fontWeight: FontWeight.w800,
                    fontSize: 22,
                    fontFamily: 'Roboto')),
            Text(currentUser != null ? currentUser!.rank.toString() : '0',
                style: const TextStyle(
                    color: Colors.black,
                    fontWeight: FontWeight.w600,
                    fontSize: 26,
                    fontFamily: 'Roboto')),
          ]),
        ],
      ),
    );
  }

  Future<void> setCurrentUserLeaderBoardData() async {
    String userId = await storageService.getString('userId');
    LeaderBoardModel leaderboard =
        leaderBoardController.getLeaderBoardData(userId);
    setState(() {
      currentUser = leaderboard;
    });
  }
}

==> progamification-0.0.38.tar.gz: lib/src/components/user_details.dart <==
import 'package:flutter/material.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:get/get.dart';

class UserDetails extends StatefulWidget {
  const UserDetails({super.key});

  @override
  State<UserDetails> createState() => _UserDetailsState();
}

class _UserDetailsState extends State<UserDetails> {
  final LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  final GamificationStorageService storageService =
      Get.find<GamificationStorageService>();

  LeaderBoardModel? currentUser = LeaderBoardModel();
  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";
  @override
  void initState() {
    setCurrentUserLeaderBoardData();
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(
          top: MediaQuery.of(context).size.height * 0.02,
          bottom: MediaQuery.of(context).size.height * 0.02),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          Column(crossAxisAlignment: CrossAxisAlignment.center, children: [
            const Text('Points',
                style: TextStyle(
                    color: Colors.grey,
                    fontWeight: FontWeight.w800,
                    fontSize: 22,
                    fontFamily: 'Roboto')),
            Text(currentUser != null ? currentUser!.score.toString() : '0',
                style: const TextStyle(
                    color: Colors.black,
                    fontWeight: FontWeight.w600,
                    fontSize: 26,
                    fontFamily: 'Roboto')),
          ]),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 8, vertical: 8),
            child: Container(
              width: 60,
              height: 60,
              decoration: const BoxDecoration(
                shape: BoxShape.circle,
              ),
              child: ClipOval(
                child: Image.network(
                    currentUser!.profileImageUrl.toString() + sasToken,
                    fit: BoxFit.cover,
                    loadingBuilder: (context, child, loadingProgress) =>
                        SizedBox(
                            width: 60.0,
                            height: 60.0,
                            child: Image.asset(
                                'assets/icons/profile_placeholder.png',
                                package: 'progamification')),
                    errorBuilder: (context, child, loadingProgress) => SizedBox(
                        width: 60.0,
                        height: 60.0,
                        child: Image.asset(
                            'assets/icons/profile_placeholder.png',
                            package: 'progamification'))),
              ),
            ),
          ),
          Column(crossAxisAlignment: CrossAxisAlignment.center, children: [
            const Text('Rank',
                style: TextStyle(
                    color: Colors.grey,
                    fontWeight: FontWeight.w800,
                    fontSize: 22,
                    fontFamily: 'Roboto')),
            Text(currentUser != null ? currentUser!.rank.toString() : '0',
                style: const TextStyle(
                    color: Colors.black,
                    fontWeight: FontWeight.w600,
                    fontSize: 26,
                    fontFamily: 'Roboto')),
          ]),
        ],
      ),
    );
  }

  Future<void> setCurrentUserLeaderBoardData() async {
    String userId = await storageService.getString('userId');
    LeaderBoardModel leaderboard =
        leaderBoardController.getLeaderBoardData(userId);
    setState(() {
      currentUser = leaderboard;
    });
  }
}
